from uploads import Videoids

from auth import build

class Comment(Videoids):
    def __init__(self,client_id,client_secret,limit=100,commentLimit=4,channelId=None):
    
     super().__init__(channelId=channelId,client_secret=client_secret,client_id=client_id)
     self.limit=limit
     self.commentLimit=commentLimit
     
     
    def insert_comment(self,text,is_reply: bool =False,apiKey=None,numberOfCommentsToReply: int =1,numberofComments: int =1):
      self.getVideos(limit=1)
      
      parentIds={}
      for i in self.videos:

        channel_id=self.auth.videos().list(part='snippet',
                                           id=i).execute()
        channel_id=channel_id['items'][0].get('snippet').get("channelId")
        x=0
        if is_reply:
            if not apiKey:

             raise ValueError("Provide Your Google Developer Api Key!")
            else:
              results=self.auth2.commentThreads().list(
            part='snippets,replies',
            videoId=i
        ).execute()             
              for n in results['replies']['comments'] :
                 
                 if 'snippet' in n.keys():
                   if x== numberOfCommentsToReply:
                       break
                   reply=n['snippet']
                   parentIds.update({reply['videoId']: reply['parentId']})
                   x+=1
              for i in parentIds:
                  self.auth2.commentThreads().insert(part='snippet',body=
                                                     {
  "snippet": {
    "videoId": i,
    "textOriginal": text,
    "parentId": parentIds[i]
    
  }
}
                                                     )
                  print("Commented on videos", i)
        else:
         x=0
         if x ==      numberofComments:
             break
         self.auth.commentThreads().insert(
            part='snippet',
            body=dict(
                snippet=dict(channelId=channel_id,
                             videoId=i,
                             topLevelComment=dict(
                                 snippet=dict(
                                     textOriginal=text
                                 )
                             ))
            )
        ).execute()
         x+=1
         print("Commented On Video on: ",i)
        
a=Comment(channelId="UC6EICaldcyFSUUFBc4SHfzw",client_secret='ggXZe_9G1CIxq-s91X0GoBSo',client_id='338364909367-v60uad41kfsa50sa7j4sgchqhcjki0df.apps.googleusercontent.com')

a.insert_comment('....')


import os
from googleapiclient.discovery import build
from google_auth_oauthlib.flow import InstalledAppFlow

from auth import Auth

   
class Videoids(Auth):
 def __init__(self,client_secret,client_id,channelId=None):
     super().__init__(client_id=client_id,client_secret=client_secret)
     self.auth=self.auth
     self.channelid=channelId
     
 def getSubscriptions(self):
   auth=self.auth
    
   subs=[]
   r=auth.subscriptions().list(
    part="snippet",
    mine=True,
    maxResults=1,
)
   if self.channelid:
         subs.append(self.channelid)
   else:
         
     for i in r.execute()['items']:
        #  print(i)
        #  a=open('a.json','w')
        #  json.dump(i,a)
         if "snippet" in i.keys():
          subs.append(i['snippet'].get('resourceId').get("channelId"))
   videos=[]
   uploads=[]
   for i in subs:
     r=auth.channels().list(
      part="contentDetails",
      id=i,
      ).execute()
      
      # maxResults=1,
     for i in r['items']:
        if "contentDetails" in i.keys():
            uploads.append(i['contentDetails'].get('relatedPlaylists').get("uploads"))
   
   self.uploads=uploads
 def getVideos(self,limit = 100):
     self.getSubscriptions()
     auth=self.auth
     videoids=[]
     a=0
     for  i in self.uploads:
      r=auth.playlistItems().list(part="contentDetails,snippet",playlistId=i,maxResults=limit).execute()
      for i in r['items']:
            if 'contentDetails' in i.keys():
             print(i['contentDetails'])     
             videoids.append(i['contentDetails'].get("videoId"))
     self.videos=videoids
     
     
     


from setuptools import setup, find_packages
import codecs
import os
import pip
from pip._internal.req import parse_requirements
import io
# try:
#     import pypandoc
#     long_description = pypandoc.convert('README.md', 'rst')
#     long_description = long_description.replace("\r","") # Do not forget this line
# except OSError:
#     print("Pandoc not found. Long_description conversion failure.")
#     import io
    # pandoc is not installed, fallback to using raw contents
with open('README.md') as f:
     long_description = f.read()
install_reqs = parse_requirements('requirements.txt',session=False)

# reqs is a list of requirement
# e.g. ['django==1.5.1', 'mezzanine==1.4.6']
reqs = [str(ir.requirement) for ir in install_reqs]
VERSION = '0.3'
DESCRIPTION ="A wrapper to comment on videos via your account!"
LONG_DESCRIPTION = 'A wrapper that allows you to comment on someone video with your script usefull for bots :)'

# Setting up
setup(
    name="YoutTubeComments",
    version=VERSION,
    author="KeinShin",
    author_email="<ytcomments@ytcomments.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=['ytcomment'],
    install_requires=reqs,
    keywords=['python', 'youtube', 'scraper', 'youtube', 'comments', 'commentyoutubevideo'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



from googleapiclient.discovery import build


import os
from google_auth_oauthlib.flow import InstalledAppFlow
import pickle
from google.auth.transport.requests import Request
import json

credential = None
key='AIzaSyD3VRv35apEiqasQ0eGrXk9IptgVitj-gQ'

class BuildClient:
    def __init__(self,client_id,client_secret):
        
      import json
      
      a=open("client_secrets.json")
      a=json.load(a)
      b=a['web']
      b.pop('client_id')
      # b.pop('project_id')
      b.pop("client_secret")
      b
      b['client_id'] = client_id
      # b['project_id'] = project_id
      b['client_secret'] = client_secret
      b['redirect_urls'] = ["http://localhost:8080/"]
      
      z=open("client_secrets.json",'w')
      z.truncate(0)
      json.dump(a,z)


if os.path.exists("token.pickle"):
    with open("token.pickle",'rb') as token:
        credential=pickle.load(token)


if not credential or not credential.valid:
    if credential and credential.expired and credential.refresh_token:
        print("Refreshing your token...")
        credential.refresh(Request())
    else:
        
       flow=InstalledAppFlow.from_client_secrets_file(
           "client_secrets.json",
           scopes=['https://www.googleapis.com/auth/youtube',"https://www.googleapis.com/auth/youtube.force-ssl"]
       )
       
       flow.run_local_server(port=8080,prompt="consent")
       credential = flow.credentials
       if not os.path.exists("token.pickle"):
        open("token.pickle", "a")
       print("Saving credentials for future use..")
       with open("token.pickle",'wb') as f:
           pickle.dump(credential,f) 



class Auth(BuildClient):
 def __init__(self,client_id,client_secret):
  print("Setting up Client....")
  super().__init__(client_id=client_id,client_secret=client_secret)
     
  self.auth=build("youtube","v3",credentials=credential)
   
   